@@ -1,6 +1,6 @@
 /***************************************************************************
  *   Copyright (C) 2003 by Hideki Ikemoto                                  *
- *   ikemo@users.sourceforge.jp                                            *
+ *   ikemo@wakaba.jp                                                       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -15,42 +15,25 @@
 
 #include "kitaboardviewbase.h"
 
+class Kita;
 class KURL;
 
-namespace Kita
-{
-  class Board;
-  class Category;
-}
-
 /**
- *
- * @author Hideki Ikemoto <ikemo@users.sourceforge.jp>
+ * 
+ * Hideki Ikemoto
  **/
 class KitaBoardView : public KitaBoardViewBase
 {
   Q_OBJECT
 
-  QString getCategory(const QString& line) const;
-  Kita::Board getBoard(const QString& line) const;
-  bool isBoardUrl(const KURL& url) const;
-  QPtrList<Kita::Category> getCategoryList(const QString& html) const;
-  void printCateogryList(QPtrList<Kita::Category>& list);
-
-private slots:
-  void loadBoard(QListViewItem* item);
-  void slotContextMenuRequested( QListViewItem*, const QPoint&, int );
-
 public:
   KitaBoardView(QWidget *parent, const char *name=0);
   ~KitaBoardView();
-
 public slots:
   void loadBoardList();
-  void setFont( const QFont& font );
-
+  void slotLoadBoard(QListViewItem* item);
 signals:
-  void clicked( const Kita::Board& board );
+  void signalLoadBoard(const KURL& url, const QString& boardName);
 };
 
 #endif
