@@ -14,7 +14,6 @@
 #include <qwidget.h>
 #include <kurl.h>
 #include "kitasubjectviewbase.h"
-#include "part/kita2ch.h"
 
 class Kita;
 class KListViewItem;
@@ -36,12 +35,12 @@ public slots:
   void loadThread(QListViewItem* item);
   void slotLoadBoard(const KURL& url, const QString& boardName);
   void slotHideButton(bool on);
-  void slotFontChanged(QFont& font);
 
 private: // Private attributes
-  Kita2ch::Board m_board;
+  KURL m_boardURL;
+  QString m_boardName;
   QStringList m_prevquery;
-  unsigned m_nextHitIndex;
+  int m_nextHitIndex;
   QValueList<KListViewItem*> m_hitList;
   
   void insertSearchCombo();
@@ -53,8 +52,7 @@ private slots:
   void slotSearchButton();
 
 signals:
-  void loadBoardCompleted(const KURL&);
-  void signalShowThread(const Kita2ch::Board& board, const Kita2ch::Thread& thread);
+  void signalShowThread(const KURL& datURL, const KURL& boardURL, const QString& boardName);
   void signalSubjectListClicked(QListViewItem* item);
 };
 
