@@ -4,9 +4,6 @@
 #include <kio/job.h>
 #include <khtml_part.h>
 
-#include "kitahtmlpart.h"
-#include "libkita/board.h"
-
 //static const char * version = $VERSION$;
 static const char * version = "1.0";
 
@@ -21,7 +18,7 @@ KAboutData * KitaThreadPart::createAboutData() // needed by GenericFactory
 	    version, 
 	    "2ch thread dat viewer plugin.", 
 	    KAboutData::License_GPL, 
-	    "(C) 2003 Konqueror-plugin no hito, (C) 2003 Hideki Ikemoto",
+	    "(C) 2003 Konqueror-plugin no hito, (C) 2001 Hideki Ikemoto",
 	    "http://pc.2ch.net/linux/",
 	    "no-mail"
 	    );
@@ -67,7 +64,7 @@ KitaThreadPart::KitaThreadPart(  QWidget *parentWidget, const char *, QObject *p
     connect( m_threadview, SIGNAL(popupMenu(KXMLGUIClient *, const QPoint&, const KURL&, const QString&, mode_t)),
 	      m_extension, SIGNAL(popupMenu(KXMLGUIClient *, const QPoint&, const KURL&, const QString&, mode_t)) );
     KParts::BrowserExtension * ext;
-    ext = m_threadview->browserExtension();
+    ext = m_threadview->threadPart->browserExtension();
     connect( ext, SIGNAL(infoMessage(const QString&)),
 	      m_extension, SIGNAL(infoMessage(const QString&)) ); 
     connect( ext, SIGNAL(selectionInfo(const KURL::List&)),
@@ -94,29 +91,29 @@ KParts::BrowserExtension * KitaThreadPart::browserExtension() const
 
 bool KitaThreadPart::openURL( const KURL& _url )
 {
-    qDebug("  KitaThreadPart::openURL _url: %s\n", _url.url().latin1() );
+    printf("  KitaThreadPart::openURL _url: %s\n", _url.url().latin1() );
     m_url = _url;
     emit setWindowCaption( m_url.url() );
-    connect( m_threadview, SIGNAL( showThreadCompleted(const KURL&) ),
-             this, SLOT( slotOpenURLResult() ) );
-
-    Kita::Board board( m_url.upURL().upURL() );
-    m_threadview->showThread( Kita::Thread( board, m_url ) );
+    connect( m_threadview, SIGNAL( showThreadCompleted() ),
+	     this, SLOT( slotOpenURLResult() ) );
+    m_threadview->slotShowThread( m_url, m_url.upURL().upURL() );
     emit started( 0 );
     return true;
 }
 
 bool KitaThreadPart::closeURL()
 {
-  m_threadview->killJob();
-  return true;
+    if ( m_threadview->m_currentJob ) {
+	m_threadview->m_currentJob->kill();
+    }
+    return true;
 }
 
 void KitaThreadPart::slotOpenURLResult()
 {
-    disconnect( m_threadview, SIGNAL( showThreadCompleted(const KURL&) ),
+    disconnect( m_threadview, SIGNAL( showThreadCompleted() ),
 	     this, SLOT( slotOpenURLResult() ) );
-    emit setWindowCaption( m_threadview->threadName() );
+    emit setWindowCaption( m_threadview->threadSubject() );
     emit completed();
 }
 
@@ -124,7 +121,7 @@ void KitaThreadPart::guiActivateEvent ( KParts::GUIActivateEvent *event )
 {
     //KParts::ReadOnlyPart::guiActivateEvent( event );
     if ( event->activated() )
-        emit setWindowCaption( m_threadview->threadName() );
+        emit setWindowCaption( m_threadview->threadSubject() );
 }
 
 KitaThreadBrowserExtension::KitaThreadBrowserExtension( KitaThreadPart * parent )
